@@ -1,4 +1,3 @@
-#define NEIGHBOR4
 /* -*- Mode: C; tab-width: 4 -*- */
 /* bug --- Michael Palmiter's simulated evolution */
 
@@ -73,7 +72,7 @@ static argtype vars[] =
 };
 static OptionStruct desc[] =
 {
-        {"-neighbors num", "squares 4 or 8, hexagons 6"},
+	{"-neighbors num", "squares 4 or 8, hexagons 6"},
 	{"-/+eyes", "turn on/off eyes"}
 };
 
@@ -113,15 +112,9 @@ ModStruct   bug_description =
 #define MINGRIDSIZE 24
 #define MINSIZE 1
 #define ANGLES 360
-#ifdef NEIGHBORS
-#define NEIGHBORKINDS 6
 #define MAXNEIGHBORS 12
-#else
-#define MAXNEIGHBORS 8
-#define NEIGHBORKINDS 3
-#endif
 
-/* Relative bug moves */
+/* Relative hex bug moves */
 /* Forward, Right, Hard Right, Reverse, Hard Left, Left */
 
 /* Bug data */
@@ -132,6 +125,10 @@ typedef struct {
 	int         col, row;
 	int         gene[MAXNEIGHBORS];
 	double      gene_prob[MAXNEIGHBORS];
+#if EXTRA_GENES
+	int         lgene[MAXNEIGHBORS];
+	double      lgene_prob[MAXNEIGHBORS];
+#endif
 } bugstruct;
 
 /* Doublely linked list */
@@ -167,16 +164,18 @@ typedef struct {
 
 static double genexp[MAXGENE - MINGENE + 1];
 
-static char plots[NEIGHBORKINDS] =
-#ifdef NEIGHBORS
-{3, 4, 6, 8, 9, 12};		/* Neighborhoods */
-#else
-{4, 6, 8};		/* Neighborhoods */
+static char plots[] =
+{3, 4, 6, 8,
+#ifdef NUMBER_9
+ 9,
 #endif
+ 12};		/* Neighborhoods */
+
+#define NEIGHBORKINDS (long) (sizeof plots / sizeof *plots)
 
 static bugfarmstruct *bugfarms = NULL;
 
-#ifdef NEIGHBORS
+#if 0
 static void
 position_of_neighbor(bugfarmstruct * bp, int dir, int *pcol, int *prow)
 {
@@ -249,112 +248,81 @@ position_of_neighbor(bugfarmstruct * bp, int dir, int *pcol, int *prow)
 				(void) fprintf(stderr, "wrong direction %d\n", dir);
 		}
 	} else {		/* TRI */
-		if ((col + row) % 2) {	/* right */
-			switch (dir) {
-				case 0:
-					col = col - 1;
-					break;
-				case 30:
-				case 40:
-					col = col - 1;
+		switch (dir) {
+			case 0:
+				col = col + 1;
+				break;
+			case 20:
+			case 30:
+			case 40:
+				col = col + 1;
+				row = row - 1;
+				break;
+			case 60:
+				if ((col + row) % 2) {	/* right */
 					row = row - 1;
-					break;
-				case 60:
-					col = col - 1;
-					row = row - 2;
-					break;
-				case 80:
-				case 90:
-					row = row - 2;
-					break;
-				case 120:
-					row = row - 1;
-					break;
-				case 150:
-				case 160:
-					col = col + 1;
-					row = row - 1;
-					break;
-				case 180:
-					col = col + 1;
-					break;
-				case 200:
-				case 210:
-					col = col + 1;
-					row = row + 1;
-					break;
-				case 240:
-					row = row + 1;
-					break;
-				case 270:
-				case 280:
-					row = row + 2;
-					break;
-				case 300:
-					col = col - 1;
-					row = row + 2;
-					break;
-				case 320:
-				case 330:
-					col = col - 1;
-					row = row + 1;
-					break;
-				default:
-					(void) fprintf(stderr, "wrong direction %d\n", dir);
-			}
-		} else {	/* left */
-			switch (dir) {
-				case 0:
-					col = col + 1;
-					break;
-				case 30:
-				case 40:
-					col = col + 1;
-					row = row + 1;
-					break;
-				case 60:
-					col = col + 1;
-					row = row + 2;
-					break;
-				case 80:
-				case 90:
-					row = row + 2;
-					break;
-				case 120:
-					row = row + 1;
-					break;
-				case 150:
-				case 160:
-					col = col - 1;
-					row = row + 1;
-					break;
-				case 180:
-					col = col - 1;
-					break;
-				case 200:
-				case 210:
-					col = col - 1;
-					row = row - 1;
-					break;
-				case 240:
-					row = row - 1;
-					break;
-				case 270:
-				case 280:
-					row = row - 2;
-					break;
-				case 300:
+				} else { /* left */
 					col = col + 1;
 					row = row - 2;
-					break;
-				case 320:
-				case 330:
-					col = col + 1;
+				}
+				break;
+			case 80:
+			case 90:
+			case 100:
+				row = row - 2;
+				break;
+			case 120:
+				if ((col + row) % 2) {	/* right */
+					col = col - 1;
+					row = row - 2;
+				} else { /* left */
 					row = row - 1;
-					break;
-				default:
-					(void) fprintf(stderr, "wrong direction %d\n", dir);
-			}
+				}
+				break;
+			case 140:
+			case 150:
+			case 160:
+				col = col - 1;
+				row = row - 1;
+				break;
+			case 180:
+				col = col - 1;
+				break;
+			case 200:
+			case 210:
+			case 220:
+				col = col - 1;
+				row = row + 1;
+				break;
+			case 240:
+				if ((col + row) % 2) {	/* right */
+					col = col - 1;
+					row = row + 2;
+				} else { /* left */
+					row = row + 1;
+				}
+				break;
+			case 260:
+			case 270:
+			case 280:
+				row = row + 2;
+				break;
+			case 300:
+				if ((col + row) % 2) {	/* right */
+					row = row + 1;
+				} else { /* left */
+					col = col + 1;
+					row = row + 2;
+				}
+				break;
+			case 320:
+			case 330:
+			case 340:
+				col = col + 1;
+				row = row + 1;
+				break;
+			default:
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 		}
 	}
 	*pcol = col;
@@ -372,6 +340,9 @@ screen2grid(bugfarmstruct *bp, int sx, int sy, int x, int y)
 		*x = (sx + 1) / 2 - 1;
 	} else if (bp->neighbors == 4 || bp->neighbors == 8) {
 		*x = sx / 2;
+	} else {		/* TRI */
+		/* Wrong but... */
+		*x = sx / 3;
 	}
 }
 
@@ -385,84 +356,173 @@ grid2screen(bugfarmstruct *bp, int x, int y, int *sx, int *sy)
 		*sx = 2 * x + 1 + !(y & 1);
 	} else if (bp->neighbors == 4 || bp->neighbors == 8) {
 		*sx = x * 2 + 1;
+	} else {		/* TRI */
+		*sx = x * 3 + 1 + ((y & 1) ? (x & 1) : !(x & 1));
 	}
 }
 
-/* This is slightly different than ant since it increases clockwise from
-   y axis as opposed to increasing counterclockwise from x-axis.
-   There is no reason for this difference other than laziness in syncing
-   them back up.
- */
 static char
-compassmove(bugfarmstruct * bp, int x, int y, int dir, int *nx, int *ny)
+dirmove(bugfarmstruct * bp, int x, int y, int dir, int *nx, int *ny)
 {
 	if (bp->neighbors == 6) {
 		switch (dir) {
 			case 0:
-				*ny = y - 1;
-				*nx = x + (int) !(y & 1);
-				return (*ny >= 0 && *nx < bp->ncols - !(*ny & 1));
-			case 60:
 				*ny = y;
 				*nx = x + 1;
 				return (*nx < bp->ncols - !(*ny & 1));
-			case 120:
-				*ny = y + 1;
+			case 60:
+				*ny = y - 1;
 				*nx = x + (int) !(y & 1);
-				return (*ny < bp->nrows && *nx < bp->ncols - !(*ny & 1));
-			case 180:
-				*ny = y + 1;
-				*nx = x - (int) (y & 1);
-				return (*ny < bp->nrows && *nx >= 0);
-			case 240:
-				*ny = y;
-				*nx = x - 1;
-				return (*nx >= 0);
-			case 300:
+				return (*ny >= 0 && *nx < bp->ncols - !(*ny & 1));
+			case 120:
 				*ny = y - 1;
 				*nx = x - (int) (y & 1);
 				return (*ny >= 0 && *nx >= 0);
+			case 180:
+				*ny = y;
+				*nx = x - 1;
+				return (*nx >= 0);
+			case 240:
+				*ny = y + 1;
+				*nx = x - (int) (y & 1);
+				return (*ny < bp->nrows && *nx >= 0);
+			case 300:
+				*ny = y + 1;
+				*nx = x + (int) !(y & 1);
+				return (*ny < bp->nrows && *nx < bp->ncols - !(*ny & 1));
 			default:
-				return 0;
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 		}
 	} else if (bp->neighbors == 4 || bp->neighbors == 8) {
 		switch (dir) {
 			case 0:
-				*ny = y - 1;
-				*nx = x;
-				return (*ny >= 0);
+				*ny = y;
+				*nx = x + 1;
+				return (*nx < bp->ncols);
 			case 45:
 				*ny = y - 1;
 				*nx = x + 1;
 				return (*ny >= 0 && *nx < bp->ncols);
 			case 90:
-				*ny = y;
-				*nx = x + 1;
-				return (*nx < bp->ncols);
-			case 135:
-				*ny = y + 1;
-				*nx = x + 1;
-				return (*ny < bp->nrows && *nx < bp->ncols);
-			case 180:
-				*ny = y + 1;
+				*ny = y - 1;
 				*nx = x;
-				return (*ny < bp->nrows);
+				return (*ny >= 0);
+			case 135:
+				*ny = y - 1;
+				*nx = x - 1;
+				return (*ny >= 0 && *nx >= 0);
+			case 180:
+				*ny = y;
+				*nx = x - 1;
+				return (*nx >= 0);
 			case 225:
 				*ny = y + 1;
 				*nx = x - 1;
 				return (*ny < bp->nrows && *nx >= 0);
 			case 270:
-				*ny = y;
-				*nx = x - 1;
-				return (*nx >= 0);
+				*ny = y + 1;
+				*nx = x;
+				return (*ny < bp->nrows);
 			case 315:
-				*ny = y - 1;
-				*nx = x - 1;
-				return (*ny >= 0 && *nx >= 0);
+				*ny = y + 1;
+				*nx = x + 1;
+				return (*ny < bp->nrows && *nx < bp->ncols);
 			default:
-				return 0;
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
+		}
+	} else {		/* TRI */
+		switch (dir) {
+			case 0:
+				*nx = x + 1;
+				*ny = y;
+				return (*nx < bp->ncols);
+			case 20:
+			case 30:
+			case 40:
+				*nx = x + 1;
+				*ny = y - 1;
+				return (*nx < bp->ncols && *ny >= 0);
+			case 60:
+				if ((x + y) % 2) {  /* right */
+					*nx = x;
+					*ny = y - 1;
+					return (*ny >= 0);
+				} else { /* left */
+					*nx = x + 1;
+					*ny = y - 2;
+					return (*nx < bp->ncols && *ny >= 0);
+				}
+			case 80:
+			case 90:
+			case 100:
+				*nx = x;
+				*ny = y - 2;
+				return (*ny >= 0);
+			case 120:
+				if ((x + y) % 2) {  /* right */
+					*nx = x - 1;
+					*ny = y - 2;
+					return (*nx >= 0 && *ny >= 0);
+				} else { /* left */
+					*nx = x;
+					*ny = y - 1;
+					return (*ny >= 0);
+				}
+			case 140:
+			case 150:
+			case 160:
+				*nx = x - 1;
+				*ny = y - 1;
+				return (*nx >= 0 && *ny >= 0);
+			case 180:
+				*nx = x - 1;
+				*ny = y;
+				return (*nx >= 0);
+			case 200:
+			case 210:
+			case 220:
+				*nx = x - 1;
+				*ny = y + 1;
+				return (*nx >= 0 && *ny < bp->nrows);
+			case 240:
+				if ((x + y) % 2) {  /* right */
+					*nx = x - 1;
+					*ny = y + 2;
+					return (*nx >= 0 && *ny < bp->nrows);
+				} else { /* left */
+					*nx = x;
+					*ny = y + 1;
+					return (*ny < bp->nrows);
+				}
+			case 260:
+			case 270:
+			case 280:
+				*nx = x;
+				*ny = y + 2;
+				return (*ny < bp->nrows);
+			case 300:
+				if ((x + y) % 2) {  /* right */
+					*nx = x;
+					*ny = y + 1;
+					return (*ny < bp->nrows);
+				} else { /* left */
+					*nx = x + 1;
+					*ny = y + 2;
+					return (*nx < bp->ncols && *ny < bp->nrows);
+				}
+			case 320:
+			case 330:
+			case 340:
+				*nx = x + 1;
+				*ny = y + 1;
+				return (*nx < bp->ncols && *ny < bp->nrows);
+			default:
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 		}
 	}
+	*nx = -1;
+	*ny = -1;
+	return 0;
 }
 
 /* This keeps bugs from walking over each other and escaping off the screen */
@@ -472,7 +532,7 @@ has_neighbor(bugfarmstruct * bp, int col, int row)
 	int         colrow = col + row * bp->ncols;
 
 	if (bp->neighbors == 6) {
-		if ((row > 0) && (bp->arr[colrow - bp->ncols]))
+		if ((row > 0) && bp->arr[colrow - bp->ncols])
 			return True;
 		if ((row < bp->nrows - 1) && bp->arr[colrow + bp->ncols])
 			return True;
@@ -497,11 +557,12 @@ has_neighbor(bugfarmstruct * bp, int col, int row)
 			}
 		}
 	} else if (bp->neighbors == 4 || bp->neighbors == 8) {
-		if ((row > 0) && (bp->arr[colrow - bp->ncols]))
+		/* Same for both because the bug square takes up the space regardless */
+		if ((row > 0) && bp->arr[colrow - bp->ncols])
 			return True;
 		if ((row < bp->nrows - 1) && bp->arr[colrow + bp->ncols])
 			return True;
-		if ((col > 0) && (bp->arr[colrow - 1]))
+		if ((col > 0) && bp->arr[colrow - 1])
 			return True;
 		if ((col < bp->ncols - 1) && bp->arr[colrow + 1])
 			return True;
@@ -513,6 +574,21 @@ has_neighbor(bugfarmstruct * bp, int col, int row)
 			return True;
 		if (row < bp->nrows - 1 && col < bp->ncols - 1 && bp->arr[colrow + bp->ncols + 1])
 			return True;
+	} else {		/* TRI */
+		/* Same for all three neighbor kinds. Only care about 3
+		   adjacent spots because that is all the squares will
+		   overlap.*/
+		if (((row & 1) && (col & 1)) || ((!(row & 1)) && (!(col & 1)))) {
+			if ((col < bp->ncols - 1) && bp->arr[colrow + 1])
+				return True;
+		} else {
+			if ((col > 0) && bp->arr[colrow - 1])
+				return True;
+		}
+		if ((row > 0) && bp->arr[colrow - bp->ncols])
+			return True;
+		if ((row < bp->nrows - 1) && bp->arr[colrow + bp->ncols])
+			return True;
 	}
 	return False;
 }
@@ -539,7 +615,7 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 	bugfarmstruct *bp = &bugfarms[MI_SCREEN(mi)];
 	Display *display = MI_DISPLAY(mi);
 	Window window = MI_WINDOW(mi);
-	int         ccol, crow, compassdir;
+	int         ccol, crow;
 	GC          gc;
 
 	if (MI_NPIXELS(mi) > 3) {
@@ -564,12 +640,6 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 
 	if (bp->eyes && bp->xs >= 1 && bp->ys >= 1) { /* Draw Eyes */
 		XSetForeground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
-		/* convert from compass direction */
-		if (bp->neighbors == 6) {
-			direction = (420 - direction) % ANGLES;
-		} else if (bp->neighbors == 4 || bp->neighbors == 8) {
-			direction = (450 - direction) % ANGLES;
-		}
 		switch (direction) {
 			case 0:
 				XDrawPoint(display, window, MI_GC(mi),
@@ -579,6 +649,9 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 					ccol + 3 * bp->xs - 2,
 					crow + 3 * bp->ys / 2 + 1);
 					break;
+			case 20:
+			case 30:
+			case 40:
 			case 45:
 			case 60:
 				XDrawPoint(display, window, MI_GC(mi),
@@ -588,7 +661,9 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 					ccol + 3 * bp->xs - 2,
 					crow + 2);
 				break;
+			case 80:
 			case 90:
+			case 100:
 				XDrawPoint(display, window, MI_GC(mi),
 					ccol + 3 * bp->xs / 2 - 1,
 					crow + 1);
@@ -598,6 +673,9 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 				break;
 			case 120:
 			case 135:
+			case 140:
+			case 150:
+			case 160:
 				XDrawPoint(display, window, MI_GC(mi),
 					ccol + 2,
 					crow + 1);
@@ -613,6 +691,9 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 					ccol + 1,
 					crow + 3 * bp->ys / 2 + 1);
 				break;
+			case 200:
+			case 210:
+			case 220:
 			case 225:
 			case 240:
 				XDrawPoint(display, window, MI_GC(mi),
@@ -622,7 +703,9 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 					ccol + 1,
 					crow + 3 * bp->ys - 3);
 				break;
+			case 260:
 			case 270:
+			case 280:
 				XDrawPoint(display, window, MI_GC(mi),
 					ccol + 3 * bp->xs / 2 - 1,
 					crow + 3 * bp->ys - 2);
@@ -632,6 +715,9 @@ drawabug(ModeInfo * mi, int col, int row, unsigned int color, int direction)
 				break;
 			case 300:
 			case 315:
+			case 320:
+			case 330:
+			case 340:
 				XDrawPoint(display, window, MI_GC(mi),
 					ccol + 3 * bp->xs - 3,
 					crow + 3 * bp->ys - 2);
@@ -768,10 +854,21 @@ dirbug(bugstruct * info, int local_neighbors)
 	int         i;
 
 	prob = (double) LRAND() / MAXRAND;
-	for (i = 0; i < local_neighbors; i++) {
-		sum += info->gene_prob[i];
-		if (prob < sum)
-			return i;
+#if EXTRA_GENES
+	if ((local_neighbors % 2) && !((info->col + info->row) & 1)) {
+		for (i = 0; i < local_neighbors; i++) {
+			sum += info->lgene_prob[i];
+			if (prob < sum)
+				return i;
+		}
+	} else
+#endif
+	{
+		for (i = 0; i < local_neighbors; i++) {
+			sum += info->gene_prob[i];
+			if (prob < sum)
+				return i;
+		}
 	}
 	return local_neighbors - 1;	/* Could miss due to rounding */
 }
@@ -796,13 +893,32 @@ mutatebug(bugstruct * info, int local_neighbors)
 		sum += genexp[info->gene[gene] + MAXGENE];
 	for (gene = 0; gene < local_neighbors; gene++)
 		info->gene_prob[gene] = genexp[info->gene[gene] + MAXGENE] / sum;
+#if EXTRA_GENES
+	if (local_neighbors % 2) {
+		sum = 0.0;
+		gene = NRAND(local_neighbors);
+		if (LRAND() & 1) {
+			if (info->lgene[gene] == MAXGENE)
+				return;
+			info->lgene[gene]++;
+		} else {
+			if (info->lgene[gene] == MINGENE)
+				return;
+			info->lgene[gene]--;
+		}
+		for (gene = 0; gene < local_neighbors; gene++)
+			sum += genexp[info->lgene[gene] + MAXGENE];
+		for (gene = 0; gene < local_neighbors; gene++)
+			info->lgene_prob[gene] = genexp[info->lgene[gene] + MAXGENE] / sum;
+	}
+#endif
 }
 
 static void
 makebacteria(ModeInfo * mi,
 	     int n, int startx, int starty, int width, int height, Bool draw)
 {
-	int         nbacteria = 0, ntries = 0, col, row, colrow;
+	int         nbacteria = 0, ntries = 0, col = 0, row, colrow;
 	bugfarmstruct *bp = &bugfarms[MI_SCREEN(mi)];
 
 	/* Make bacteria but if can not, exit */
@@ -813,7 +929,7 @@ makebacteria(ModeInfo * mi,
 				col = NRAND(width - (!(row & 1))) + startx;
 			else
 				col = startx;
-		} else if (bp->neighbors == 4 || bp->neighbors == 8) {
+		} else { /* RECT or TRI */
 			col = NRAND(width) + startx;
 		}
 		colrow = col + row * bp->ncols;
@@ -848,7 +964,7 @@ init_bug(ModeInfo * mi)
 	int         size = MI_SIZE(mi);
 	XGCValues   gcv;
 	bugfarmstruct *bp;
-	int         nbugs = 0, ntries = 0, col, row, gene, colrow, i;
+	int         nbugs = 0, ntries = 0, col = 0, row, gene, colrow, i;
 	int         nccols, ncrows;
 	double      sum;
 	bugstruct   info;
@@ -914,8 +1030,15 @@ init_bug(ModeInfo * mi)
 	bp->xs = bp->ys;
 	nccols = MAX(bp->width / bp->xs - 2, 2);
 	ncrows = MAX(bp->height / bp->ys - 1, 2);
-	bp->ncols = nccols / 2;
 	bp->nrows = ncrows / 2;
+	if ((bp->neighbors % 2) || bp->neighbors == 12) {
+		bp->ncols = nccols / 3;
+		if (bp->ncols & 1)
+			bp->ncols--;	/* Must be odd for no wrap */
+		if (!(bp->nrows & 1))
+			bp->nrows--;	/* Must be even for no wrap */
+	} else
+		bp->ncols = nccols / 2;
 	if (bp->neighbors == 6 && !(bp->nrows & 1))
 		bp->nrows--;	/* Must be odd for no wrap */
 	bp->xb = (bp->width - bp->xs * nccols) / 2;
@@ -927,15 +1050,29 @@ init_bug(ModeInfo * mi)
 		(void) free((void *) bp->bacteria);
 	bp->bacteria = (char *) calloc(bp->ncols * bp->nrows, sizeof (char));
 
-	bp->edenwidth = bp->ncols / 4;
 	bp->edenheight = bp->nrows / 4;
-	if (bp->neighbors == 6 && bp->edenheight && !(bp->edenheight & 1))
+	bp->edenwidth = bp->ncols / 4;
+	if ((bp->neighbors % 2) || bp->neighbors == 12) {
+		if (bp->edenwidth & 1)
+			bp->edenwidth--;
+		if (!(bp->edenheight & 1))
+			bp->edenheight--;
+	} else if (bp->neighbors == 6 && bp->edenheight && !(bp->edenheight & 1))
 		bp->edenheight--;	/* Make sure its odd */
 	bp->eden = (bp->edenwidth > 1 && bp->edenheight > 1);
 	if (bp->eden) {
 		bp->edenstartx = NRAND(bp->ncols - bp->edenwidth);
 		bp->edenstarty = NRAND(bp->nrows - bp->edenheight);
-		if (bp->neighbors == 6 && (bp->edenstarty & 1)) {
+		if ((bp->neighbors % 2) || bp->neighbors == 12) {
+			if (bp->edenstartx & 1) {
+				bp->edenstartx--;
+				bp->eden = (bp->edenwidth > 1);
+			}
+			if (bp->edenstarty & 1) {
+				bp->edenstarty--;
+				bp->eden = (bp->edenheight > 1);
+			}
+		} else if (bp->neighbors == 6 && (bp->edenstarty & 1)) {
 			bp->edenstarty--;
 			bp->eden = (bp->edenheight > 1);
 		}
@@ -950,11 +1087,11 @@ init_bug(ModeInfo * mi)
 	bp->painted = False;
 
 	if (MI_IS_FULLRANDOM(mi)) {
-                bp->eyes = (Bool) (LRAND() & 1);
-        } else {
-                bp->eyes = eyes;
-        }
-        bp->eyes = (bp->eyes && bp->xs > 1 && bp->ys > 1);
+		bp->eyes = (Bool) (LRAND() & 1);
+	} else {
+		bp->eyes = eyes;
+	}
+	bp->eyes = (bp->eyes && bp->xs > 1 && bp->ys > 1);
 
 	/* Try to make bugs, but if can not, exit */
 	while (bp->nbugs < nbugs && ntries < 2 * nbugs) {
@@ -964,7 +1101,7 @@ init_bug(ModeInfo * mi)
 				col = NRAND(bp->ncols - (!(row & 1)));
 			else
 				col = 0;
-		} else if (bp->neighbors == 4 || bp->neighbors == 8) {
+		} else { /* RECT or TRI */
 			col = NRAND(bp->ncols);
 		}
 		colrow = col + row * bp->ncols;
@@ -975,7 +1112,8 @@ init_bug(ModeInfo * mi)
 			info.energy = INITENERGY;
 			info.direction = NRAND(bp->neighbors);
 			for (gene = 0; gene < bp->neighbors; gene++)
-#if 0				/* Some creationalism, may create gliders or twirlers */
+#if 0
+				/* Some creationalism, may create gliders or twirlers */
 				do {
 					double      temp = (double) LRAND() / MAXRAND;
 
@@ -991,6 +1129,28 @@ init_bug(ModeInfo * mi)
 				sum += genexp[info.gene[gene] + MAXGENE];
 			for (gene = 0; gene < bp->neighbors; gene++)
 				info.gene_prob[gene] = genexp[info.gene[gene] + MAXGENE] / sum;
+#if EXTRA_GENES
+			if (bp->neighbors % 2) {
+				for (gene = 0; gene < bp->neighbors; gene++)
+#if 0
+				/* Some creationalism, may create gliders or twirlers */
+					do {
+						double      temp = (double) LRAND() / MAXRAND;
+
+						info.lgene[gene] = ((int) (1.0 / (1.0 - temp * temp)) - 1) *
+							((LRAND() & 1) ? -1 : 1);
+					} while (info.lgene[gene] > MAXGENE / 2 ||
+						 info.lgene[gene] < MINGENE / 2);
+#else /* Jitterbugs, evolve or die */
+					info.lgene[gene] = 0;
+#endif
+				sum = 0;
+				for (gene = 0; gene < bp->neighbors; gene++)
+					sum += genexp[info.lgene[gene] + MAXGENE];
+				for (gene = 0; gene < bp->neighbors; gene++)
+					info.lgene_prob[gene] = genexp[info.lgene[gene] + MAXGENE] / sum;
+			}
+#endif
 			if (MI_NPIXELS(mi) > 3)
 				info.color = NRAND(MI_NPIXELS(mi));
 			else
@@ -1006,8 +1166,7 @@ init_bug(ModeInfo * mi)
 		     False);
 	if (bp->eden)
 		makebacteria(mi, bp->edenwidth * bp->edenheight / 2,
-		bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight,
-			     False);
+		bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight, False);
 	bp->redrawing = 1;
 	bp->redrawpos = 0;
 }
@@ -1017,7 +1176,8 @@ void
 draw_bug(ModeInfo * mi)
 {
 	bugfarmstruct *bp = &bugfarms[MI_SCREEN(mi)];
-	int         col, row, ncol, nrow, colrow, ncolrow, absdir, tryit;
+	int         col, row, ncol = -1, nrow = -1, colrow, ncolrow;
+	int         absdir = 0, tryit, dir;
 
 	MI_IS_DRAWN(mi) = True;
 
@@ -1049,7 +1209,14 @@ draw_bug(ModeInfo * mi)
 				}
 				absdir = (bp->currbug->info.direction +
 					  dirbug(&bp->currbug->info, bp->neighbors)) % bp->neighbors;
-			} while (!compassmove(bp, col, row, absdir * ANGLES / bp->neighbors,
+				dir = absdir * ANGLES / bp->neighbors;
+				if (bp->neighbors % 2) {
+					if ((col + row) & 1)
+						dir = (3 * ANGLES / 2 - dir) % ANGLES;
+					else
+						dir = (ANGLES - dir) % ANGLES;
+				}
+			} while (!dirmove(bp, col, row, dir,
 			  &ncol, &nrow) || has_neighbor(bp, ncol, nrow) ||
 			  bp->arr[ncol + nrow * bp->ncols]);
 			bp->currbug->info.age++;
