@@ -39,12 +39,13 @@ static const char sccsid[] = "@(#)forest.c	4.07 97/11/24 xlockmore";
  "*ncolors: 100 \n"
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
 
+#ifdef MODE_forest
+
 ModeSpecOpt forest_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -172,6 +173,8 @@ draw_forest(ModeInfo * mi)
 	short       x, y, x_2, y_2, len, c = 0;
 	float       a, as;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (fp->time < fp->ntrees) {
 
 		x = RANGE_RAND(0, fp->width);
@@ -196,9 +199,6 @@ draw_forest(ModeInfo * mi)
 		draw_tree(mi, x_2, y_2, (len * REDUCE) / 100, a, as, c, 1);
 	}
 	if (++fp->time > MI_CYCLES(mi)) {
-#ifdef STANDALONE
-		erase_full_window(display, MI_WINDOW(mi));
-#endif /* STANDALONE */
 		init_forest(mi);
 	}
 }
@@ -217,3 +217,5 @@ refresh_forest(ModeInfo * mi)
 {
 	MI_CLEARWINDOW(mi);
 }
+
+#endif /* MODE_forest */
