@@ -1,4 +1,12 @@
+#ifdef VMS
+/* Xlib.h for VMS is not (yet) compatible with C++ *
+ * The resulting warnings are switched off here    */
+#pragma message disable nosimpint
+#endif
 #include <X11/Intrinsic.h>
+#ifdef VMS
+#pragma message enable nosimpint
+#endif
 #include "xlock.h"
 
 #include "i_linkage.h"
@@ -33,7 +41,7 @@ invert_draw(spherestruct * gp)
   glRotatef(gp->view_rotx, 1.0, 0.0, 0.0);
   glRotatef(gp->view_roty, 0.0, 1.0, 0.0);
   glRotatef(gp->view_rotz, 0.0, 0.0, 1.0);
-  
+
   /* default parameters */
 
   corrstart = 0;
@@ -56,9 +64,9 @@ invert_draw(spherestruct * gp)
   parts = "+0+1+2+3+4+5+6+7";
   time = (cos((M_PI*gp->time)/gp->numsteps)+1.0)/2.0;
   binary = 0;
-  
+
   /* draw it here */
-  
+
   if (gp->partlist == NULL)
     gp->partlist = parse_parts(parts);
 
@@ -67,24 +75,24 @@ invert_draw(spherestruct * gp)
   if (gp->construction) {
     glNewList(gp->frames+gp->time, GL_COMPILE);
 
-    if (time >= uncorrstart && uncorrstart >= 0) 
-      printScene(UnCorrugate, umin, umax, du, vmin, vmax, dv, 
+    if (time >= uncorrstart && uncorrstart >= 0)
+      printScene(UnCorrugate, umin, umax, du, vmin, vmax, dv,
 		 (time - uncorrstart) / (1.0 - uncorrstart), binary);
-    else if (time >= unpushstart && unpushstart >= 0) 
+    else if (time >= unpushstart && unpushstart >= 0)
       printScene(UnPush, umin, umax, du, vmin, vmax, dv,
-		 (time - unpushstart) / 
+		 (time - unpushstart) /
 		 (((uncorrstart < 0) ? 1.0 : uncorrstart) - unpushstart), binary);
-    else if (time >= twiststart && twiststart >= 0) 
-      printScene(Twist, umin, umax, du, vmin, vmax, dv, 
-		 (time - twiststart) / 
+    else if (time >= twiststart && twiststart >= 0)
+      printScene(Twist, umin, umax, du, vmin, vmax, dv,
+		 (time - twiststart) /
 		 (((unpushstart < 0) ? 1.0 : unpushstart) - twiststart), binary);
-    else if (time >= pushstart && pushstart >= 0) 
+    else if (time >= pushstart && pushstart >= 0)
       printScene(PushThrough, umin, umax, du, vmin, vmax, dv,
-		 (time - pushstart) / 
+		 (time - pushstart) /
 		 (((twiststart < 0) ? 1.0 : twiststart) - pushstart), binary);
-    else if (time >= corrstart && corrstart >= 0) 
+    else if (time >= corrstart && corrstart >= 0)
       printScene(Corrugate, umin, umax, du, vmin, vmax, dv,
-		 (time - corrstart) / 
+		 (time - corrstart) /
 		 (((pushstart < 0) ? 1.0 : pushstart) - corrstart), binary);
     glEndList();
   }
@@ -94,13 +102,13 @@ invert_draw(spherestruct * gp)
       if(gp->partlist[k] & (j<0 ? PART_NEG : PART_POS)) {
 	double t = 2*M_PI * (j < 0 ? n_strips-1-k : k) / n_strips;
 	double s = sin(t), c = cos(t);
-	
+
 	GLdouble m[16];
 	m[0] = j*c; m[4] = -s; m[8] =  0; m[12] = 0;
 	m[1] = j*s; m[5] =  c; m[9] =  0, m[13] = 0;
 	m[2] =   0; m[6] =  0; m[10] = j; m[14] = 0;
 	m[3] =   0; m[7] =  0; m[11] = 0; m[15] = 1;
-	
+
 	glPushMatrix();
 	glMultMatrixd(m);
 	glCallList(gp->frames+gp->time);
@@ -111,4 +119,3 @@ invert_draw(spherestruct * gp)
 
   glPopMatrix();
 }
-
