@@ -57,6 +57,8 @@ static const char sccsid[] = "@(#)pyro.c	4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+#ifdef MODE_pyro
+
 ModeSpecOpt pyro_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -601,3 +603,5 @@ refresh_pyro(ModeInfo * mi)
 		MI_CLEARWINDOW(mi);
 	}
 }
+
+#endif /* MODE_pyro */
